@@ -27,11 +27,11 @@ class UrlHandler
 public:
 	virtual ~UrlHandler() {}
 
-	virtual bool isUrlValid(const QString &url) = 0;
+	virtual bool isUrlValid(const QByteArray &url) = 0;
 
 	virtual void convertUrlsToHtml(HtmlDocument &document) = 0;
 
-	virtual void openUrl(const QString &url, bool disableMenu = false) = 0;
+	virtual void openUrl(const QByteArray &url, bool disableMenu = false) = 0;
 };
 
 #endif // URL_HANDLER_H
