@@ -39,11 +39,11 @@ private slots:
 public:
 	GaduUrlHandler();
 
-	bool isUrlValid(const QString &url);
+	bool isUrlValid(const QByteArray &url);
 
 	void convertUrlsToHtml(HtmlDocument &document);
 
-	void openUrl(const QString &url, bool disableMenu);
+	void openUrl(const QByteArray &url, bool disableMenu);
 };
 
 #endif // GADU_URL_HANDLER_H
